# {{ project.name }} - Content Management System
# Gobstopper Framework Requirements

# Core framework
wopr

# Database
asyncpg>=0.29.0          # PostgreSQL async driver
databases[postgresql]>=0.8.0

# Authentication & Security
passlib[bcrypt]>=1.7.4   # Password hashing
python-jose>=3.3.0       # JWT handling
cryptography>=41.0.0     # Crypto operations

# Content Management
bleach>=6.1.0            # HTML sanitization
markdown>=3.5.0          # Markdown processing
python-slugify>=8.0.0    # URL slug generation
pillow>=10.1.0           # Image processing

# Search
elasticsearch>=8.11.0    # Full-text search (optional)
whoosh>=2.7.4           # Lightweight search alternative

# File Handling
python-multipart>=0.0.6 # File upload support
aiofiles>=23.2.1        # Async file operations

# Media Processing
imageio>=2.33.0         # Image manipulation
python-magic>=0.4.27    # File type detection

# Email (for notifications)
aiosmtplib>=3.0.1       # Async SMTP
jinja2>=3.1.2           # Email templates

# Caching & Sessions
redis>=5.0.0            # Session storage
aioredis>=2.0.1         # Async Redis client

# Background Tasks
celery>=5.3.0           # Alternative task queue (optional)

# API & Documentation
pydantic>=2.5.0         # Data validation
fastapi-users>=12.1.0   # User management (optional)

# Monitoring & Logging
structlog>=23.2.0       # Structured logging
prometheus-client>=0.19.0 # Metrics

# Development Dependencies (add to requirements-dev.txt)
# pytest>=7.4.0
# pytest-asyncio>=0.21.0
# pytest-cov>=4.1.0
# black>=23.0.0
# ruff>=0.1.0
# mypy>=1.7.0